@@ -1,16 +1,18 @@
 """
 Faraday Penetration Test IDE
-Copyright (C) 2013  Infobyte LLC (http://www.infobytesec.com/)
+Copyright (C) 2013  Infobyte LLC (https://www.faradaysec.com/)
 See the file 'doc/LICENSE' for the license information
 
 """
+# Standard library imports
 import logging
 import os
 import socket
+import re
 from urllib.parse import urlsplit
 
 SERVICE_MAPPER = None
-
+CVE_regex = re.compile(r'CVE-\d{4}-\d{4,7}')
 logger = logging.getLogger(__name__)
 
 
@@ -125,3 +127,8 @@ def get_severity_from_cvss(cvss):
                 return severity
     except ValueError:
         return 'unclassified'
+
+
+def its_cve(cves: list):
+    r = [cve for cve in cves if CVE_regex.match(cve)]
+    return r
