@@ -56,6 +56,9 @@ class AppScanParser:
             type_id = item.attrib['id']
             name = item.find("name").text
             issue_types[type_id] = name
+            cve = item.find("cve")
+            if cve and cve.text:
+                issue_types[f"{type_id}_cve"] = cve.text
         return issue_types
 
     @staticmethod
@@ -111,7 +114,7 @@ class AppScanParser:
         dast_issues = []
         for item in tree:
             entity = self.entities[item.find("entity/ref").text]
-            host = entity["host"]
+            host = entity["host"].replace('\\','/')
             port = entity["port"]
             name = self.issue_types[item.find("issue-type/ref").text]
             severity = 0 if item.find("severity-id") is None else int(item.find("severity-id").text)
@@ -139,6 +142,8 @@ class AppScanParser:
             else:
                 cve = None
                 cve_url = None
+            if cve is None:
+                cve = self.issue_types.get(f"{item.find('issue-type/ref').text}_cve", None)
             host_key = f"{host}-{port}"
             issue_data = {
                 "host": host,
@@ -154,10 +159,10 @@ class AppScanParser:
                 "response": response,
                 "website": entity['website'],
                 "path": entity['path'],
-                "external_id": cve
+                "cve": []
             }
             if cve:
-                issue_data["ref"].append(cve)
+                issue_data["cve"].append(cve)
             if cve_url:
                 issue_data["ref"].append(cve_url)
             if cwe:
@@ -177,7 +182,7 @@ class AppScanParser:
         sast_issues = []
         for item in tree:
             name = self.issue_types[item.find("issue-type/ref").text]
-            source_file = item.attrib["filename"]
+            source_file = item.attrib["filename"].replace('\\','/')
             severity = 0 if item.find("severity-id") is None else int(item.find("severity-id").text)
             description = item.find("fix/item/general/text").text
             resolution = "" if item.find("variant-group/item/issue-information/fix-resolution-text") is None \
@@ -210,10 +215,11 @@ class AppScanParser:
                 "desc": description,
                 "ref": [],
                 "resolution": resolution,
-                "external_id": cve
+                "cve": []
             }
+
             if cve:
-                issue_data["ref"].append(cve)
+                issue_data["cve"].append(cve)
             if cve_url:
                 issue_data["ref"].append(cve_url)
             if cwe:
