@@ -4,12 +4,13 @@ Copyright (C) 2020  Infobyte LLC (http://www.infobytesec.com/)
 See the file 'doc/LICENSE' for the license information
 
 """
-import socket
+import subprocess
 import re
+import sys
 import json
 import dateutil
-from collections import defaultdict
 from urllib.parse import urlparse
+from packaging import version
 from faraday_plugins.plugins.plugin import PluginMultiLineJsonFormat
 from faraday_plugins.plugins.plugins_utils import resolve_hostname
 
@@ -32,9 +33,9 @@ class NucleiPlugin(PluginMultiLineJsonFormat):
         super().__init__(*arg, **kwargs)
         self.id = "nuclei"
         self.name = "Nuclei"
-        self.plugin_version = "1.0.1"
-        self.version = "2.3.8"
-        self.json_keys = {"matched", "templateID", "host"}
+        self.plugin_version = "1.0.2"
+        self.version = "2.5.3"
+        self.json_keys = {"matched-at", "template-id", "host"}
         self._command_regex = re.compile(r'^(sudo nuclei|nuclei|\.\/nuclei|^.*?nuclei)\s+.*?')
         self.xml_arg_re = re.compile(r"^.*(-o\s*[^\s]+).*$")
         self._use_temp_file = True
@@ -63,8 +64,12 @@ class NucleiPlugin(PluginMultiLineJsonFormat):
                 status='open',
                 version='',
                 description='web server')
-            matched = vuln_dict.get('matched')
-            matched_data = urlparse(matched)
+            matched = vuln_dict.get('matched-at', '')
+            if matched:
+                matched_data = urlparse(matched)
+            else:
+                print('Version not supported, use nuclei 2.5.3 or higher')
+                sys.exit(1)
             reference = vuln_dict["info"].get('reference', [])
             if not reference:
                 reference = []
@@ -97,9 +102,10 @@ class NucleiPlugin(PluginMultiLineJsonFormat):
                 method = request.split(" ")[0]
             else:
                 method = ""
-            data = [f"Matched: {vuln_dict.get('matched')}",
+
+            data = [f"Matched: {vuln_dict.get('matched-at')}",
                     f"Tags: {vuln_dict['info'].get('tags', '')}",
-                    f"Template ID: {vuln_dict['templateID']}"]
+                    f"Template ID: {vuln_dict.get('template-id', '')}"]
 
             name = vuln_dict["info"].get("name")
             run_date = vuln_dict.get('timestamp')
@@ -124,15 +130,11 @@ class NucleiPlugin(PluginMultiLineJsonFormat):
                 params=matched_data.params,
                 path=matched_data.path,
                 data="\n".join(data),
-                external_id=f"NUCLEI-{vuln_dict.get('templateID', '')}",
+                external_id=f"NUCLEI-{vuln_dict.get('template-id', '')}",
                 run_date=run_date
             )
-    
+
     def processCommandString(self, username, current_path, command_string):
-        """
-        Adds the -oX parameter to get xml output to the command string that the
-        user has set.
-        """
         super().processCommandString(username, current_path, command_string)
         arg_match = self.xml_arg_re.match(command_string)
         if arg_match is None:
@@ -142,7 +144,22 @@ class NucleiPlugin(PluginMultiLineJsonFormat):
         else:
             return re.sub(arg_match.group(1),
                           r"--json -irr -o %s" % self._output_file_path,
-                          command_string)            
+                          command_string)
+
+    def canParseCommandString(self, current_input):
+        can_parse = super().canParseCommandString(current_input)
+        if can_parse:
+            try:
+                proc = subprocess.Popen([self.command, '-version'], stderr=subprocess.PIPE)
+                output = proc.stderr.read()
+                match = re.search(r"Current Version: ([0-9.]+)", output.decode('UTF-8'))
+                if match:
+                    nuclei_version = match.groups()[0]
+                    return version.parse(nuclei_version) >= version.parse("2.5.3")
+                else:
+                    return False
+            except Exception as e:
+                return False
 
 
 def createPlugin(ignore_info=False):
